==> fltk-docs-1.3.6-1-aarch64.pkg.tar.xz: usr/share/doc/fltk/html/classFl__Preferences.js <==
var classFl__Preferences =
[
    [ "Entry", "structFl__Preferences_1_1Entry.html", "structFl__Preferences_1_1Entry" ],
    [ "Name", "classFl__Preferences_1_1Name.html", "classFl__Preferences_1_1Name" ],
    [ "Node", "classFl__Preferences_1_1Node.html", "classFl__Preferences_1_1Node" ],
    [ "RootNode", "classFl__Preferences_1_1RootNode.html", "classFl__Preferences_1_1RootNode" ],
    [ "ID", "classFl__Preferences.html#a7050f8b1c0cbb70693e61bcfbf4f5853", null ],
    [ "Root", "classFl__Preferences.html#a0947b73d778ca66b9fbb97b75bbbd7cb", [
      [ "SYSTEM", "classFl__Preferences.html#a0947b73d778ca66b9fbb97b75bbbd7cba057fd9ac75376136f30efb0d700e8db4", null ],
      [ "USER", "classFl__Preferences.html#a0947b73d778ca66b9fbb97b75bbbd7cbaaf4354ca5ac4df110c2fd1fc36c61053", null ]
    ] ],
    [ "Fl_Preferences", "classFl__Preferences.html#af8418ff8af933d22dbb70a082525a74e", null ],
    [ "Fl_Preferences", "classFl__Preferences.html#a7e2ec1496b7eb3cc5b2b9e8f6584c979", null ],
    [ "Fl_Preferences", "classFl__Preferences.html#a44b60d610214f1ff60e9603babdea664", null ],
    [ "Fl_Preferences", "classFl__Preferences.html#a402ba68241bfefeabcd3665613d81607", null ],
    [ "Fl_Preferences", "classFl__Preferences.html#ac87308454632a4c0a9feb040f42a1a39", null ],
    [ "Fl_Preferences", "classFl__Preferences.html#a20b8a66cd9fda6f727e391847653c4df", null ],
    [ "Fl_Preferences", "classFl__Preferences.html#a49a5569fb0b4f270ff8b343f34d11eac", null ],
    [ "Fl_Preferences", "classFl__Preferences.html#ae2811816dd028d35d8b6b1cafd4f2e44", null ],
    [ "~Fl_Preferences", "classFl__Preferences.html#a0eb024a8350c344303755fedb1582185", null ],
    [ "clear", "classFl__Preferences.html#ae0fc8533d4cfb2d8c7e67b71b7080129", null ],
    [ "deleteAllEntries", "classFl__Preferences.html#af73078b80334cc3f43542f4862de402b", null ],
    [ "deleteAllGroups", "classFl__Preferences.html#a9d7563cd64c29348cd5c4d4c14e97614", null ],
    [ "deleteEntry", "classFl__Preferences.html#a3a1710633307e8e79ba8fd89a803042e", null ],
    [ "deleteGroup", "classFl__Preferences.html#a6602c3104b2c5259160cb7e0fe5dd335", null ],
    [ "entries", "classFl__Preferences.html#a9004c55f8c0c9515943b96853ea17940", null ],
    [ "entry", "classFl__Preferences.html#a61bd91e8c3ee2a3f8bccd00ee2a65b8d", null ],
    [ "entryExists", "classFl__Preferences.html#a05c3d7cbf364d5d1ed350ef33850f702", null ],
    [ "flush", "classFl__Preferences.html#a4d49e9959bc26fdc20641534497f3792", null ],
    [ "get", "classFl__Preferences.html#a30e9d1ae031b06f501779c8937533740", null ],
    [ "get", "classFl__Preferences.html#a1074a165aa35687955568c7a13ba1462", null ],
    [ "get", "classFl__Preferences.html#a0d71373c6af5199bc1bb1fb955cb3a64", null ],
    [ "get", "classFl__Preferences.html#a128339abc1a1ff6bca073de3a62b2cb3", null ],
    [ "get", "classFl__Preferences.html#a0991a0bea2800ce5cd362ff6a778c0d3", null ],
    [ "get", "classFl__Preferences.html#a4b0188c9976139103b5c49761c8b765a", null ],
    [ "get", "classFl__Preferences.html#ae909187975eefda3c8bbef494296bc9f", null ],
    [ "getUserdataPath", "classFl__Preferences.html#acf3c545a4006ef50b091ed45b6f7ce2a", null ],
    [ "group", "classFl__Preferences.html#a8aeb2bab88aea893c700533c5dea3d41", null ],
    [ "groupExists", "classFl__Preferences.html#a4009efec7d5505a8060ca7a95c1bee2e", null ],
    [ "groups", "classFl__Preferences.html#a70cfbe5245270b772806e085603a7ab8", null ],
    [ "id", "classFl__Preferences.html#a1170302365aa48fbd04335ca52c20319", null ],
    [ "name", "classFl__Preferences.html#a6ff11b679bec179ebb211c31f8e46f2e", null ],
    [ "path", "classFl__Preferences.html#aaf2e1a8f1904abb41f3cfa195ae9df41", null ],
    [ "set", "classFl__Preferences.html#a1bbc84064bf5f2675b10724567505fd5", null ],
    [ "set", "classFl__Preferences.html#acc689e9cdf957f7636992d275498d72b", null ],
    [ "set", "classFl__Preferences.html#a929db63f2f0d24d11c64ee929688b39e", null ],
    [ "set", "classFl__Preferences.html#a0b2d3935a8ba462d27d0e3c2c9e33841", null ],
    [ "set", "classFl__Preferences.html#a3d06e7b756a9c87acc508b835286d569", null ],
    [ "set", "classFl__Preferences.html#a8bd606d0dd993488d149204ee0841925", null ],
    [ "set", "classFl__Preferences.html#a1928e8ca3f21f66304951b757f24d70a", null ],
    [ "size", "classFl__Preferences.html#aca6793ffe782ad4a55c604caed794ea9", null ],
    [ "Node", "classFl__Preferences.html#a6db9d28bd448a131448276ee03de1e6d", null ],
    [ "RootNode", "classFl__Preferences.html#a3bb397989a4485545d4d65709ce3c863", null ],
    [ "node", "classFl__Preferences.html#ae5633500be10cea17e2ffb2791f05b6c", null ],
    [ "rootNode", "classFl__Preferences.html#a1d05b8bf3baf9255771e7c57aa8620cc", null ]
];

==> fltk-docs-1.3.9-1-aarch64.pkg.tar.xz: usr/share/doc/fltk/html/classFl__Preferences.js <==
var classFl__Preferences =
[
    [ "Entry", "structFl__Preferences_1_1Entry.html", null ],
    [ "Name", "classFl__Preferences_1_1Name.html", "classFl__Preferences_1_1Name" ],
    [ "Node", "classFl__Preferences_1_1Node.html", null ],
    [ "RootNode", "classFl__Preferences_1_1RootNode.html", null ],
    [ "ID", "classFl__Preferences.html#a7050f8b1c0cbb70693e61bcfbf4f5853", null ],
    [ "Root", "classFl__Preferences.html#a0947b73d778ca66b9fbb97b75bbbd7cb", [
      [ "SYSTEM", "classFl__Preferences.html#a0947b73d778ca66b9fbb97b75bbbd7cba057fd9ac75376136f30efb0d700e8db4", null ],
      [ "USER", "classFl__Preferences.html#a0947b73d778ca66b9fbb97b75bbbd7cbaaf4354ca5ac4df110c2fd1fc36c61053", null ]
    ] ],
    [ "Fl_Preferences", "classFl__Preferences.html#af8418ff8af933d22dbb70a082525a74e", null ],
    [ "Fl_Preferences", "classFl__Preferences.html#a7e2ec1496b7eb3cc5b2b9e8f6584c979", null ],
    [ "Fl_Preferences", "classFl__Preferences.html#a44b60d610214f1ff60e9603babdea664", null ],
    [ "Fl_Preferences", "classFl__Preferences.html#a402ba68241bfefeabcd3665613d81607", null ],
    [ "Fl_Preferences", "classFl__Preferences.html#ac87308454632a4c0a9feb040f42a1a39", null ],
    [ "Fl_Preferences", "classFl__Preferences.html#a20b8a66cd9fda6f727e391847653c4df", null ],
    [ "Fl_Preferences", "classFl__Preferences.html#a49a5569fb0b4f270ff8b343f34d11eac", null ],
    [ "Fl_Preferences", "classFl__Preferences.html#ae2811816dd028d35d8b6b1cafd4f2e44", null ],
    [ "~Fl_Preferences", "classFl__Preferences.html#a0eb024a8350c344303755fedb1582185", null ],
    [ "clear", "classFl__Preferences.html#ae0fc8533d4cfb2d8c7e67b71b7080129", null ],
    [ "deleteAllEntries", "classFl__Preferences.html#af73078b80334cc3f43542f4862de402b", null ],
    [ "deleteAllGroups", "classFl__Preferences.html#a9d7563cd64c29348cd5c4d4c14e97614", null ],
    [ "deleteEntry", "classFl__Preferences.html#a3a1710633307e8e79ba8fd89a803042e", null ],
    [ "deleteGroup", "classFl__Preferences.html#a6602c3104b2c5259160cb7e0fe5dd335", null ],
    [ "entries", "classFl__Preferences.html#a9004c55f8c0c9515943b96853ea17940", null ],
    [ "entry", "classFl__Preferences.html#a61bd91e8c3ee2a3f8bccd00ee2a65b8d", null ],
    [ "entryExists", "classFl__Preferences.html#a05c3d7cbf364d5d1ed350ef33850f702", null ],
    [ "flush", "classFl__Preferences.html#a4d49e9959bc26fdc20641534497f3792", null ],
    [ "get", "classFl__Preferences.html#a30e9d1ae031b06f501779c8937533740", null ],
    [ "get", "classFl__Preferences.html#a1074a165aa35687955568c7a13ba1462", null ],
    [ "get", "classFl__Preferences.html#a0d71373c6af5199bc1bb1fb955cb3a64", null ],
    [ "get", "classFl__Preferences.html#a128339abc1a1ff6bca073de3a62b2cb3", null ],
    [ "get", "classFl__Preferences.html#a0991a0bea2800ce5cd362ff6a778c0d3", null ],
    [ "get", "classFl__Preferences.html#a4b0188c9976139103b5c49761c8b765a", null ],
    [ "get", "classFl__Preferences.html#ae909187975eefda3c8bbef494296bc9f", null ],
    [ "getUserdataPath", "classFl__Preferences.html#acf3c545a4006ef50b091ed45b6f7ce2a", null ],
    [ "group", "classFl__Preferences.html#a8aeb2bab88aea893c700533c5dea3d41", null ],
    [ "groupExists", "classFl__Preferences.html#a4009efec7d5505a8060ca7a95c1bee2e", null ],
    [ "groups", "classFl__Preferences.html#a70cfbe5245270b772806e085603a7ab8", null ],
    [ "id", "classFl__Preferences.html#a1170302365aa48fbd04335ca52c20319", null ],
    [ "name", "classFl__Preferences.html#a7910bff72c890fe556b7daad8189d00c", null ],
    [ "path", "classFl__Preferences.html#a4535be6edd38d07fce5b60f8ccb50874", null ],
    [ "set", "classFl__Preferences.html#a1bbc84064bf5f2675b10724567505fd5", null ],
    [ "set", "classFl__Preferences.html#acc689e9cdf957f7636992d275498d72b", null ],
    [ "set", "classFl__Preferences.html#a929db63f2f0d24d11c64ee929688b39e", null ],
    [ "set", "classFl__Preferences.html#a0b2d3935a8ba462d27d0e3c2c9e33841", null ],
    [ "set", "classFl__Preferences.html#a3d06e7b756a9c87acc508b835286d569", null ],
    [ "set", "classFl__Preferences.html#a8bd606d0dd993488d149204ee0841925", null ],
    [ "set", "classFl__Preferences.html#a1928e8ca3f21f66304951b757f24d70a", null ],
    [ "size", "classFl__Preferences.html#aca6793ffe782ad4a55c604caed794ea9", null ]
];
